.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _presentation-technical:

Technical architecture
======================

.. toctree::
   :maxdepth: 1

    Overview of hierarchical parallelism <technical.hierarchical>
    Plugin system <technical.plugin>
    HPC integration <technical.hpc>
